import { select, arc, scaleTime, extent,line,curveBasis,
        max, scaleLinear, axisBottom, nest,
        axisLeft, scaleOrdinal, schemeCategory10 } from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');


const render= data => {
//dimensions
const margin= {top:20, right:40, bottom:50,left:50}  
const innerWidth= width-margin.left-margin.right
const innerHeight= height-margin.top-margin.bottom

const xValue= d=>d.timestamp
const yValue= d=>d.value
const colorValue = d => d.telescope;

// now the scales

 const xscale = d3.scaleTime()
.domain(d3.extent(data, xValue))
.range([0, innerWidth])
.nice();

const yscale= scaleLinear()
.domain([0,max(data, yValue)])
.range([innerHeight, 0])

const colorScale= scaleOrdinal(schemeCategory10)

// now for the axis

const g= svg.append('g')
.attr('transform', `translate(${margin.left},${margin.top})`)

const xAxis= g.append('g')
.call(axisBottom(xscale).tickSizeOuter(0))
.attr('transform', `translate(0,${innerHeight})`)
const yAxis= g.append('g')
.call(axisLeft(yscale))

// now to draw the line
const lineGenerator= line()
.x(d=>xscale(xValue(d)))
.y(d=>yscale(yValue(d)))
.curve(curveBasis)

const nested= nest()
.key(colorValue)
.entries(data)

colorScale.domain(nested.map(d=> d.key))
console.log(colorScale.domain())
  
g.selectAll('.line-path')
.data(nested)
.enter()
.append('path')
.attr('class', 'line-path')
.attr('d',d=>lineGenerator(d.values)) 
.attr('stroke',function(d){return colorScale(d.key)}) 

}

// first check data is clean

d3.csv('data.csv')
.then(function(data){
data.forEach(function(d){
d.value= +d.value
d.timestamp= new Date(d.timestamp)  
})  
console.log(data)
render(data)
})







